## ----echo = FALSE-------------------------------------------------------------
example <- paste0(
  rprojroot::find_package_root_file(),
  "/inst/examples/deckgl-api-reference/point-cloud-layer.R"
)
do.call(knitr::read_chunk, list(path = example))

## ----point-cloud-layer, eval = FALSE------------------------------------------
#  sample_data <- paste0(
#    "https://raw.githubusercontent.com/",
#    "uber-common/deck.gl-data/",
#    "master/website/pointcloud.json"
#  )
#  
#  properties <- list(
#    pickable = TRUE,
#    coordinateSystem = JS("deck.COORDINATE_SYSTEM.METER_OFFSETS"),
#    coordinateOrigin = c(-122.4, 37.74),
#    pointSize = 4,
#    getPosition = ~position,
#    getNormal = ~normal,
#    getColor = ~color,
#    lightSettings = list(),
#    getTooltip = JS("object => object.position.join(', ')")
#  )
#  
#  deck <- deckgl(pitch = 45, zoom = 10.5) %>%
#    add_point_cloud_layer(data = sample_data, properties = properties) %>%
#    add_mapbox_basemap()
#  
#  if (interactive()) deck

